@@ -2,10 +2,11 @@ use super::*;
 use hex;
 
 #[test]
-fn test_buffer() {
+fn test_ptrbuffer() {
     let data = hex::decode("deadbeefabad1deadeadbea7defaced1").unwrap();
-    let buffer = Buffer::from_ref(&data);
+    let buffer = PtrBuffer::new(data.as_ptr(), data.len());
 
+    assert_eq!(buffer.as_ptr(), data.as_ptr());
     assert_eq!(buffer.len(), data.len());
     assert_eq!(buffer.as_ptr(), data.as_ptr());
     unsafe { assert_eq!(buffer.eob(), data.as_ptr().add(data.len())); }
@@ -30,16 +31,24 @@ fn test_buffer() {
 
     let struct_data = struct_result.unwrap();
     assert_eq!(struct_data.deadbe, [0xDE, 0xAD, 0xBE]);
-    unsafe { assert_eq!(struct_data.efab, 0xABEF); }
-    unsafe { assert_eq!(struct_data.ad1deade, 0xDEEA1DAD); }
+
+    let efab_unaligned = struct_data.efab;
+    assert_eq!(efab_unaligned, 0xABEF);
+
+    let ad1deade_unaligned = struct_data.ad1deade;
+    assert_eq!(ad1deade_unaligned, 0xDEEA1DAD);
 
     let struct_result = buffer.get_ref::<StructTest>(4);
     assert!(struct_result.is_ok());
 
     let struct_data = struct_result.unwrap();
     assert_eq!(struct_data.deadbe, [0xAB, 0xAD, 0x1D]);
-    unsafe { assert_eq!(struct_data.efab, 0xDEEA); }
-    unsafe { assert_eq!(struct_data.ad1deade, 0xDEA7BEAD); }
+
+    let efab_unaligned = struct_data.efab;
+    assert_eq!(efab_unaligned, 0xDEEA);
+
+    let ad1deade_unaligned = struct_data.ad1deade;
+    assert_eq!(ad1deade_unaligned, 0xDEA7BEAD);
 
     let read_result = buffer.read(8, 4);
     assert!(read_result.is_ok());
@@ -98,7 +107,7 @@ fn test_vecbuffer() {
     assert!(buffer.write_ref::<u32>(4, &0xEFBEADDE).is_ok());
     assert!(buffer.contains_ref::<u32>(&0xEFBEADDE));
 
-    buffer.append(&mut vec![0xAB, 0xAD, 0x1D, 0xEA]);
+    buffer.append(&vec![0xAB, 0xAD, 0x1D, 0xEA]);
     assert!(buffer.contains([0xAB, 0xAD, 0x1D, 0xEA]));
 
     let rhs = buffer.split_off(0x8);
@@ -107,7 +116,7 @@ fn test_vecbuffer() {
     buffer.resize(0xC, 0x00);
     assert!(buffer.write_ref::<u32>(0x8, &0x74EEFFC0).is_ok());
 
-    buffer.extend_from_data(&rhs);
+    buffer.append(&rhs);
     assert!(buffer.contains([0xAB, 0xAD, 0x1D, 0xEA]));
     assert!(buffer.contains([0xC0, 0xFF, 0xEE, 0x74]));
 
